==> plotly-3.1.1-py2.py3-none-any.whl: plotly/validators/cone/__init__.py <==
from ._zsrc import ZsrcValidator
from ._z import ZValidator
from ._ysrc import YsrcValidator
from ._y import YValidator
from ._xsrc import XsrcValidator
from ._x import XValidator
from ._wsrc import WsrcValidator
from ._w import WValidator
from ._vsrc import VsrcValidator
from ._visible import VisibleValidator
from ._v import VValidator
from ._usrc import UsrcValidator
from ._uid import UidValidator
from ._u import UValidator
from ._textsrc import TextsrcValidator
from ._text import TextValidator
from ._stream import StreamValidator
from ._sizeref import SizerefValidator
from ._sizemode import SizemodeValidator
from ._showscale import ShowscaleValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._scene import SceneValidator
from ._reversescale import ReversescaleValidator
from ._opacity import OpacityValidator
from ._name import NameValidator
from ._lightposition import LightpositionValidator
from ._lighting import LightingValidator
from ._legendgroup import LegendgroupValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator
from ._colorscale import ColorscaleValidator
from ._colorbar import ColorBarValidator
from ._cmin import CminValidator
from ._cmax import CmaxValidator
from ._cauto import CautoValidator
from ._autocolorscale import AutocolorscaleValidator
from ._anchor import AnchorValidator

==> plotly-3.7.0rc1-py2.py3-none-any.whl: plotly/validators/cone/__init__.py <==
from ._zsrc import ZsrcValidator
from ._z import ZValidator
from ._ysrc import YsrcValidator
from ._y import YValidator
from ._xsrc import XsrcValidator
from ._x import XValidator
from ._wsrc import WsrcValidator
from ._w import WValidator
from ._vsrc import VsrcValidator
from ._visible import VisibleValidator
from ._v import VValidator
from ._usrc import UsrcValidator
from ._uirevision import UirevisionValidator
from ._uid import UidValidator
from ._u import UValidator
from ._textsrc import TextsrcValidator
from ._text import TextValidator
from ._stream import StreamValidator
from ._sizeref import SizerefValidator
from ._sizemode import SizemodeValidator
from ._showscale import ShowscaleValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._scene import SceneValidator
from ._reversescale import ReversescaleValidator
from ._opacity import OpacityValidator
from ._name import NameValidator
from ._lightposition import LightpositionValidator
from ._lighting import LightingValidator
from ._legendgroup import LegendgroupValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hovertextsrc import HovertextsrcValidator
from ._hovertext import HovertextValidator
from ._hovertemplatesrc import HovertemplatesrcValidator
from ._hovertemplate import HovertemplateValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator
from ._colorscale import ColorscaleValidator
from ._colorbar import ColorBarValidator
from ._cmin import CminValidator
from ._cmid import CmidValidator
from ._cmax import CmaxValidator
from ._cauto import CautoValidator
from ._autocolorscale import AutocolorscaleValidator
from ._anchor import AnchorValidator
